@@ -1,6 +1,11 @@
 """
 Implementation of Steam client based on ``gevent``
 
+.. warning::
+    ``steam.client`` no longer patches stdlib to make it gevent cooperative.
+    This provides flexibility if you want to use :class:`.SteamClient` with async or other modules.
+    If you want to monkey patch anyway use :meth:`steam.monkey.patch_minimal()`
+
 .. note::
     Additional features are located in separate submodules. All functionality from :mod:`.builtins` is inherited by default.
 
@@ -8,11 +13,6 @@ Implementation of Steam client based on ``gevent``
     Optional features are available as :mod:`.mixins`. This allows the client to remain light yet flexible.
 
 """
-import gevent
-import gevent.monkey
-gevent.monkey.patch_socket()
-gevent.monkey.patch_ssl()
-
 import os
 import json
 from random import random
@@ -31,7 +31,7 @@ from steam.core.crypto import sha1_hash
 from steam.steamid import SteamID
 from steam.exceptions import SteamError
 from steam.client.builtins import BuiltinBase
-from steam.utils import ip_from_int, ip_to_int
+from steam.utils import ip4_from_int, ip4_to_int
 from steam.utils.proto import proto_fill_from_dict
 
 if six.PY2:
@@ -59,8 +59,8 @@ class SteamClient(CMClient, BuiltinBase):
     login_key = None                   #: can be used for subsequent logins (no 2FA code will be required)
     chat_mode = 2                      #: chat mode (0=old chat, 2=new chat)
 
-    def __init__(self):
-        CMClient.__init__(self)
+    def __init__(self, protocol = CMClient.PROTOCOL_TCP):
+        CMClient.__init__(self, protocol)
 
         # register listners
         self.on(self.EVENT_DISCONNECTED, self._handle_disconnect)
@@ -174,7 +174,7 @@ class SteamClient(CMClient, BuiltinBase):
             data = {
                 'cell_id': self.cm_servers.cell_id,
                 'last_updated': self.cm_servers.last_updated,
-                'servers': list(zip(map(ip_from_int, msg.body.cm_addresses), msg.body.cm_ports)),
+                'servers': list(zip(map(ip4_from_int, msg.body.cm_addresses), msg.body.cm_ports)),
             }
             try:
                 with open(filepath, 'wb') as f:
@@ -539,7 +539,7 @@ class SteamClient(CMClient, BuiltinBase):
         message.body.chat_mode = self.chat_mode
 
         if login_id is None:
-            message.body.obfuscated_private_ip.v4 = ip_to_int(self.connection.local_address) ^ 0xF00DBAAD
+            message.body.obfuscated_private_ip.v4 = ip4_to_int(self.connection.local_address) ^ 0xF00DBAAD
         else:
             message.body.obfuscated_private_ip.v4 = login_id
 
