@@ -16,7 +16,7 @@ from steam.steamid import SteamID
 from steam.enums import EResult, EUniverse
 from steam.enums.emsg import EMsg
 from steam.core import crypto
-from steam.core.connection import TCPConnection
+from steam.core.connection import TCPConnection, WebSocketConnection
 from steam.core.msg import Msg, MsgProto
 from eventemitter import EventEmitter
 from steam.utils import ip4_from_int
@@ -59,6 +59,7 @@ class CMClient(EventEmitter):
 
     PROTOCOL_TCP = 0                        #: TCP protocol enum
     PROTOCOL_UDP = 1                        #: UDP protocol enum
+    PROTOCOL_WEBSOCKET = 2
     verbose_debug = False                   #: print message connects in debug
 
     auto_discovery = True                   #: enables automatic CM discovery
@@ -82,11 +83,22 @@ class CMClient(EventEmitter):
 
     def __init__(self, protocol=PROTOCOL_TCP):
         self.cm_servers = CMServerList()
+        self.protocol   = protocol
 
+        if protocol == CMClient.PROTOCOL_UDP:
+            raise ValueError('UDP is deprecated')
+            
         if protocol == CMClient.PROTOCOL_TCP:
+            self._LOG.warning("PROTOCOL_TCP is being deprecated")
             self.connection = TCPConnection()
+            
+        elif protocol == CMClient.PROTOCOL_WEBSOCKET:
+            self.connection = WebSocketConnection()
+            
         else:
-            raise ValueError("Only TCP is supported")
+            raise ValueError("Unsupported protocol")
+            
+        self._multibuf = b''
 
         self.on(EMsg.ChannelEncryptRequest, self.__handle_encrypt_request),
         self.on(EMsg.Multi, self.__handle_multi),
@@ -132,8 +144,12 @@ class CMClient(EventEmitter):
                 self._connecting = False
                 return False
 
-            if not self.cm_servers.bootstrap_from_webapi():
-                self.cm_servers.bootstrap_from_dns()
+            if self.protocol == CMClient.PROTOCOL_TCP:
+                if not self.cm_servers.bootstrap_from_webapi(protocol = self.protocol):
+                    self.cm_servers.bootstrap_from_dns()
+                    
+            elif self.protocol == CMClient.PROTOCOL_WEBSOCKET:
+                self.cm_servers.bootstrap_from_webapi(protocol = self.protocol)
 
         for i, server_addr in enumerate(cycle(self.cm_servers), start=next(i)-1):
             if retry and i >= retry:
@@ -154,6 +170,11 @@ class CMClient(EventEmitter):
         self.current_server_addr = server_addr
         self.connected = True
         self.emit(self.EVENT_CONNECTED)
+        
+        if self.protocol == CMClient.PROTOCOL_WEBSOCKET:
+            self.channel_secured = True
+            self.emit(self.EVENT_CHANNEL_SECURED)
+        
         self._recv_loop = gevent.spawn(self._recv_messages)
         self._connecting = False
         return True
@@ -244,8 +265,20 @@ class CMClient(EventEmitter):
 
     def _parse_message(self, message):
         emsg_id, = struct.unpack_from("<I", message)
-        emsg = EMsg(clear_proto_bit(emsg_id))
-
+        
+        try:
+            emsg = EMsg(clear_proto_bit(emsg_id))
+        
+        except Exception as e:
+            if len(self._multibuf):
+                self._multibuf += message
+                if not self._multibuf.endswith(b'\x00\x00'):
+                    return
+                
+                message = self._multibuf
+                self._multibuf = b''
+                return self._parse_message(message)
+                
         if not self.connected and emsg != EMsg.ClientLogOnResponse:
             self._LOG.debug("Dropped unexpected message: %s (is_proto: %s)",
                             repr(emsg),
@@ -274,7 +307,12 @@ class CMClient(EventEmitter):
                 return
 
         if self.count_listeners(emsg) or self.verbose_debug:
-            msg.parse()
+            try:
+                msg.parse()
+            
+            except Exception as e:
+                self._multibuf = message
+                return
 
         if self.verbose_debug:
             self._LOG.debug("Incoming: %s\n%s" % (repr(msg), str(msg)))
@@ -333,26 +371,63 @@ class CMClient(EventEmitter):
     def __handle_multi(self, msg):
         self._LOG.debug("Multi: Unpacking")
 
+        # Extract body
+        body_bytes = msg.body.message_body
+
+        # If server indicated uncompressed size, it's definitely gzip-compressed
         if msg.body.size_unzipped:
             self._LOG.debug("Multi: Decompressing payload (%d -> %s)" % (
-                len(msg.body.message_body),
-                msg.body.size_unzipped,
-                ))
-
-            with GzipFile(fileobj=BytesIO(msg.body.message_body)) as f:
-                data = f.read()
+                len(body_bytes), msg.body.size_unzipped,
+            ))
+            try:
+                with GzipFile(fileobj=BytesIO(body_bytes)) as f:
+                    data = f.read()
+            except Exception as exp:
+                self._LOG.exception(exp)
+                gevent.spawn(self.disconnect)
+                return
 
             if len(data) != msg.body.size_unzipped:
                 self._LOG.fatal("Unzipped size mismatch")
                 gevent.spawn(self.disconnect)
                 return
         else:
-            data = msg.body.message_body
+            # Some CMs occasionally send gzip-compressed data without size_unzipped set.
+            # Detect gzip magic and transparently decompress.
+            if body_bytes.startswith(b"\x1f\x8b\x08"):
+                self._LOG.debug("Multi: Detected gzip without size hint; decompressing (%d bytes)" % len(body_bytes))
+                try:
+                    with GzipFile(fileobj=BytesIO(body_bytes)) as f:
+                        data = f.read()
+                except Exception as exp:
+                    self._LOG.exception(exp)
+                    gevent.spawn(self.disconnect)
+                    return
+            else:
+                data = body_bytes
+
+        # Split concatenated messages (each prefixed with 4-byte little-endian size)
+        view = memoryview(data)
+        offset = 0
+        total_len = len(view)
+        while offset + 4 <= total_len:
+            try:
+                (chunk_size,) = struct.unpack_from("<I", view, offset)
+            except Exception as exp:
+                self._LOG.exception(exp)
+                break
+
+            next_offset = offset + 4 + chunk_size
+            if next_offset > total_len:
+                self._LOG.error("Multi: Truncated chunk (size=%d, available=%d)" % (chunk_size, total_len - (offset + 4)))
+                break
+
+            self._parse_message(view[offset + 4: next_offset])
+            offset = next_offset
+
+        if offset != total_len:
+            self._LOG.debug("Multi: %d trailing bytes after parsing chunks" % (total_len - offset))
 
-        while len(data) > 0:
-            size, = struct.unpack_from("<I", data)
-            self._parse_message(data[4:4+size])
-            data = data[4+size:]
 
     def __heartbeat(self, interval):
         message = MsgProto(EMsg.ClientHeartBeat)
@@ -383,7 +458,7 @@ class CMClient(EventEmitter):
 
             self._LOG.debug("Heartbeat started.")
 
-            interval = msg.body.out_of_game_heartbeat_seconds
+            interval = msg.body.heartbeat_seconds
             self._heartbeat_loop = gevent.spawn(self.__heartbeat, interval)
         else:
             self.emit(self.EVENT_ERROR, EResult(result))
@@ -472,7 +547,7 @@ class CMServerList(object):
             self._LOG.error("DNS boostrap: cm0.steampowered.com resolved no A records")
             return False
 
-    def bootstrap_from_webapi(self, cell_id=0):
+    def bootstrap_from_webapi(self, cell_id=0, protocol=CMClient.PROTOCOL_TCP):
         """
         Fetches CM server list from WebAPI and replaces the current one
 
@@ -481,24 +556,43 @@ class CMServerList(object):
         :return: booststrap success
         :rtype: :class:`bool`
         """
-        self._LOG.debug("Attempting bootstrap via WebAPI")
+        self._LOG.debug("Attempting bootstrap via WebAPI for protocol %d" % protocol)
 
         from steam import webapi
-        try:
-            resp = webapi.get('ISteamDirectory', 'GetCMList', 1, params={'cellid': cell_id,
-                                                                         'http_timeout': 3})
-        except Exception as exp:
-            self._LOG.error("WebAPI boostrap failed: %s" % str(exp))
-            return False
-
-        result = EResult(resp['response']['result'])
-
-        if result != EResult.OK:
-            self._LOG.error("GetCMList failed with %s" % repr(result))
-            return False
-
-        serverlist = resp['response']['serverlist']
-        self._LOG.debug("Recieved %d servers from WebAPI" % len(serverlist))
+        
+        if protocol == CMClient.PROTOCOL_TCP:
+            try:
+                resp = webapi.get('ISteamDirectory', 'GetCMList', 1, params={'cellid': cell_id,
+                                                                             'http_timeout': 3})
+            except Exception as exp:
+                self._LOG.error("WebAPI boostrap failed: %s" % str(exp))
+                return False
+    
+            result = EResult(resp['response']['result'])
+    
+            if result != EResult.OK:
+                self._LOG.error("GetCMList failed with %s" % repr(result))
+                return False
+    
+            serverlist = resp['response']['serverlist']
+            self._LOG.debug("Received %d servers from WebAPI" % len(serverlist))
+            
+        elif protocol == CMClient.PROTOCOL_WEBSOCKET:
+            try:
+                resp = webapi.get('ISteamDirectory', 'GetCMListForConnect', 1, params={'cmtype': 'websockets', 'http_timeout': 3})
+            except Exception as exp:
+                self._LOG.error("WebAPI boostrap failed: %s" % str(exp))
+                return False
+    
+            if not resp['response']['success']:
+                self._LOG.error("GetCMListForConnect failed with %s" % repr(resp))
+                return False
+    
+            serverlist = [server['endpoint'] for server in resp['response']['serverlist']]
+            self._LOG.debug("Received %d servers from WebAPI" % len(serverlist))
+            
+        else:
+            raise ValueError('Unsupported protocol for CMServerList')
 
         def str_to_tuple(serveraddr):
             ip, port = serveraddr.split(':')
